@@ -56,7 +56,7 @@ def main():
                 print(f"{имя_ввода} невозможно преобразовать в {имя_вывода}")
     else:
         while True:
-            print("Интерактивный Реверсивный Борп!")
+            print("Интерактивный Борп!")
             code = input(">>> ")
             (
                 result,
